Package 'wcvpdata'

Title: World Checklist of Vascular Plants Data
Description: Provides a local interface to the 'World Checklist of Vascular Plants' (WCVP) <https://powo.science.kew.org/about-wcvp> (Version 15, January 2026), sourced from 'Plants of the World Online' <https://powo.science.kew.org/>. Bundles standardized snapshots of global taxonomic and geographic distribution data for vascular plants, designed to support large-scale botanical research and biodiversity analysis directly in 'R'.
Authors: Paul E. Santos Andrade [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-6635-0375>)
Maintainer: Paul E. Santos Andrade <[email protected]>
License: GPL (>= 3)
Version: 0.5.0
Built: 2026-05-14 07:05:20 UTC
Source: https://github.com/PaulESantos/wcvpdata

Help Index


Check if the packaged version of WCVP is up to date.

Description

[Stable]

Usage

wcvp_check_version(silent = FALSE)

Arguments

silent

Suppress all messages and warnings.

Value

A logical value; TRUE if the packaged version is up to date, FALSE otherwise.

Examples

wcvp_check_version()

The World Checklist of Vascular Plants: distributions

Description

[Stable]

Usage

wcvp_checklist_distribution

Format

A data frame with 1,990,342 rows and 11 variables:

plant_locality_id

Sequential number.

plant_name_id

WCVP Identifier, corresponding to the filed of the same name in checklist_names.txt.

continent_code_l1

Numerical botanical continent code (TDWG level 1).

continent

Botanical continent (TDWG Level 1). See https://www.tdwg.org/standards/wgsrpd/ for details.

region_code_l2

Numerical botanical region code (TDWG level 2).

region

Botanical region (TDWG Level 2). See https://www.tdwg.org/standards/wgsrpd/ for details.

area_code_l3

Numerical botanical area code (TDWG level 3).

area

Botanical area (TDWG Level 3). See https://www.tdwg.org/standards/wgsrpd/ for details.

introduced

Introduced status of the taxon: 0 if native; 1 if introduced.

extinct

Local extinction status of the taxon: 0 if extant; 1 if extinct in region.

location_doubtful

Trustfulness of status: 1 if doubtfully present; else 0.

Details

A dataset containing the distribution data from the WCVP, mapped to the Biodiversity Information Standards (TDWG) World Geographical Scheme for Recording Plant Distributions (WGSRPD)

http://sftp.kew.org/pub/data-repositories/WCVP/wcvp.zip

Examples

data(wcvp_checklist_distribution)
head(wcvp_checklist_distribution)

The World Checklist of Vascular Plants: names

Description

[Stable]

Usage

wcvp_checklist_names

Format

A data frame with 1,442,392 rows and 31 variables:

plant_name_id

World Checklist of Vascular Plants (WCVP) identifier

ipni_id

International Plant Name Index (IPNI) identifier. Missing values indicate that the name has not been matched with a name in IPNI.

taxon_rank

The level in the taxonomic hierarchy where the taxon nname fits. Some infraspecific names are unranked and will have no value iin this column.

taxon_status

Indication of taxonomic opinion re the name.

family

The name of the family to which the taxon belongs. (The highest rank at which names are presented in WCVP).

genus_hybrid

Indication of hybrid status at genus level: \+ indicates a graft-chimaera and × indicates a hybrid.

genus

The name of the genus to which the record refers.

species_hybrid

Indication of hybrid status at species level: \+ indicates a graft-chimaera and × indicates a hybrid.

species

The species epithet which is combined with the genus name to make a binomial name for a species. Empty when the taxon name is at the rank of genus.

infraspecific_rank

The taxonomic rank of the infraspecific epithet. Empty where the taxon name is species rank or higher. For more information, see the International Code of Nomenclature for algae, fungi and plants: https://www.iapt-taxon.org/nomen/main.php

infraspecies

The infraspecific epithet which is combined with a binomial to make a trinomial name at infraspecific rank. Empty when taxon name is at species rank or higher.

parenthetical_author

The author of the basionym. Empty when there is no basionym.

primary_author

The author or authors who published the scientific name. Missing values indicate instances where authorship is non-applicable (e.g. autonyms) or unknown.

publication_author

The author or authors of the book where the scientific name is first published, who are different from the primary author. Missing values indicate instances where the primary author is also the author of the book or non-applicable (e.g. autonyms).

place_of_publication

The journal, book or other publication in which the taxon name was effectively published. Missing values indicate instances where publication details are unknown or non-applicable (e.g. for autonyms). Abbreviated for brevity.

volume_and_page

The volume and page numbers of the original publication of the taxon name, where "5(6): 36" is volume 5, issue 6, page 36. Missing values indicate instances where publication details are unknown or non-applicable (e.g. for autonyms). Not all records include issue number.

first_published

The year of publication of the name, enclosed in parentheses. Missing values indicate instances where publication details are unknown or non-applicable (e.g. for autonyms).

nomenclatural_remarks

Remarks on the nomenclature. Preceded by a comma and space (", ") for easy concatenation.

geographic_area

The geographic distribution of the taxon (for names of species rank or below): a generalised statement in narrative form. See https://powo.science.kew.org/about-distribution#geography for details.

lifeform_description

The lifeform (or lifeforms) of the taxon. Terms refer to a modified version of the Raunkiær system. Where there are multiple lifeforms, the most common is listed first. Missing values if unknown. See https://powo.science.kew.org/about-distribution#lifeform for a glossary of terms used.

climate_description

Habitat type of the taxon, derived from published habitat information.

taxon_name

Concatenation of genus with species and, where applicable, infraspecific epithets to make a binomial or trinomial name.

taxon_authors

Concatenation of parenthetical and primary authors. Missing values indicate instances where authorship is unknown or non-applicable (e.g. autonyms).

accepted_plant_name_id

The ID of the accepted name of this taxon. Where the taxon_status is "Accepted", this will be identical to the plant_name_id value. Maybe empty if taxon status is unplaced, illegitimate, or in some cases where the accepted name is not a vascular plant (e.g. a moss, alga or animal).

basionym_plant_name_id

ID of the original name that taxon_name was derived from (i.e. the basionym). Empty if there have been no name changes.

replaced_synonym_author

The author or authors responsible for publication of the replaced synonym. Empty when the name is not a replacement name based on another name.

homotypic_synonym

The synonym type - TRUE if homotypic synonym, otherwise NA. See more information, see the International Code of Nomenclature for algae, fungi and plants: https://www.iapt-taxon.org/nomen/main.php

parent_plant_name_id

ID for the parent genus or parent species of an accepted species or infraspecific name. Empty for non accepted names or where the parent has not yet been calculated.

powo_id

Identifier required to look up the name directly in Plants of the World Online (POWO).

hybrid_formula

Parents of hybrid.

reviewed

Flag indicating whether the family to which the taxon belongs has been peer reviewed.

...

Details

A dataset containing the taxonomic data from the WCVP (Version 15, extracted Jan 2026).

http://sftp.kew.org/pub/data-repositories/WCVP/wcvp.zip

Examples

data(wcvp_checklist_names)
head(wcvp_checklist_names)

Functions to help check the WCVP data is okay and up to date. View the version of WCVP available.

Description

[Stable]

Usage

wcvp_version(long = TRUE)

Arguments

long

Whether to return the version date with version number.

Value

A character string containing the version and date.

Examples

wcvp_version()