| Title: | World Checklist of Vascular Plants Data |
|---|---|
| Description: | Provides a local interface to the 'World Checklist of Vascular Plants' (WCVP) <https://powo.science.kew.org/about-wcvp> (Version 15, January 2026), sourced from 'Plants of the World Online' <https://powo.science.kew.org/>. Bundles standardized snapshots of global taxonomic and geographic distribution data for vascular plants, designed to support large-scale botanical research and biodiversity analysis directly in 'R'. |
| Authors: | Paul E. Santos Andrade [aut, cre, cph] (ORCID: <https://orcid.org/0000-0002-6635-0375>) |
| Maintainer: | Paul E. Santos Andrade <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 0.5.0 |
| Built: | 2026-05-14 07:05:20 UTC |
| Source: | https://github.com/PaulESantos/wcvpdata |
wcvp_check_version(silent = FALSE)wcvp_check_version(silent = FALSE)
silent |
Suppress all messages and warnings. |
A logical value; TRUE if the packaged version is up to date, FALSE otherwise.
wcvp_check_version()wcvp_check_version()
wcvp_checklist_distributionwcvp_checklist_distribution
A data frame with 1,990,342 rows and 11 variables:
Sequential number.
WCVP Identifier, corresponding to the filed of the same name in checklist_names.txt.
Numerical botanical continent code (TDWG level 1).
Botanical continent (TDWG Level 1). See https://www.tdwg.org/standards/wgsrpd/ for details.
Numerical botanical region code (TDWG level 2).
Botanical region (TDWG Level 2). See https://www.tdwg.org/standards/wgsrpd/ for details.
Numerical botanical area code (TDWG level 3).
Botanical area (TDWG Level 3). See https://www.tdwg.org/standards/wgsrpd/ for details.
Introduced status of the taxon: 0 if native; 1 if introduced.
Local extinction status of the taxon: 0 if extant; 1 if extinct in region.
Trustfulness of status: 1 if doubtfully present; else 0.
A dataset containing the distribution data from the WCVP, mapped to the Biodiversity Information Standards (TDWG) World Geographical Scheme for Recording Plant Distributions (WGSRPD)
http://sftp.kew.org/pub/data-repositories/WCVP/wcvp.zip
data(wcvp_checklist_distribution) head(wcvp_checklist_distribution)data(wcvp_checklist_distribution) head(wcvp_checklist_distribution)
wcvp_checklist_nameswcvp_checklist_names
A data frame with 1,442,392 rows and 31 variables:
World Checklist of Vascular Plants (WCVP) identifier
International Plant Name Index (IPNI) identifier. Missing values indicate that the name has not been matched with a name in IPNI.
The level in the taxonomic hierarchy where the taxon nname fits. Some infraspecific names are unranked and will have no value iin this column.
Indication of taxonomic opinion re the name.
The name of the family to which the taxon belongs. (The highest rank at which names are presented in WCVP).
Indication of hybrid status at genus level: \+ indicates a graft-chimaera and × indicates a hybrid.
The name of the genus to which the record refers.
Indication of hybrid status at species level: \+ indicates a graft-chimaera and × indicates a hybrid.
The species epithet which is combined with the genus name to make a binomial name for a species. Empty when the taxon name is at the rank of genus.
The taxonomic rank of the infraspecific epithet. Empty where the taxon name is species rank or higher. For more information, see the International Code of Nomenclature for algae, fungi and plants: https://www.iapt-taxon.org/nomen/main.php
The infraspecific epithet which is combined with a binomial to make a trinomial name at infraspecific rank. Empty when taxon name is at species rank or higher.
The author of the basionym. Empty when there is no basionym.
The author or authors who published the scientific name. Missing values indicate instances where authorship is non-applicable (e.g. autonyms) or unknown.
The author or authors of the book where the scientific name is first published, who are different from the primary author. Missing values indicate instances where the primary author is also the author of the book or non-applicable (e.g. autonyms).
The journal, book or other publication in which the taxon name was effectively published. Missing values indicate instances where publication details are unknown or non-applicable (e.g. for autonyms). Abbreviated for brevity.
The volume and page numbers of the original publication of the taxon name, where "5(6): 36" is volume 5, issue 6, page 36. Missing values indicate instances where publication details are unknown or non-applicable (e.g. for autonyms). Not all records include issue number.
The year of publication of the name, enclosed in parentheses. Missing values indicate instances where publication details are unknown or non-applicable (e.g. for autonyms).
Remarks on the nomenclature. Preceded by a comma and space (", ") for easy concatenation.
The geographic distribution of the taxon (for names of species rank or below): a generalised statement in narrative form. See https://powo.science.kew.org/about-distribution#geography for details.
The lifeform (or lifeforms) of the taxon. Terms refer to a modified version of the Raunkiær system. Where there are multiple lifeforms, the most common is listed first. Missing values if unknown. See https://powo.science.kew.org/about-distribution#lifeform for a glossary of terms used.
Habitat type of the taxon, derived from published habitat information.
Concatenation of genus with species and, where applicable, infraspecific epithets to make a binomial or trinomial name.
Concatenation of parenthetical and primary authors. Missing values indicate instances where authorship is unknown or non-applicable (e.g. autonyms).
The ID of the accepted name of this taxon. Where the taxon_status is "Accepted", this will be identical to the plant_name_id value. Maybe empty if taxon status is unplaced, illegitimate, or in some cases where the accepted name is not a vascular plant (e.g. a moss, alga or animal).
ID of the original name that taxon_name was derived from (i.e. the basionym). Empty if there have been no name changes.
The author or authors responsible for publication of the replaced synonym. Empty when the name is not a replacement name based on another name.
The synonym type - TRUE if homotypic synonym, otherwise NA. See more information, see the International Code of Nomenclature for algae, fungi and plants: https://www.iapt-taxon.org/nomen/main.php
ID for the parent genus or parent species of an accepted species or infraspecific name. Empty for non accepted names or where the parent has not yet been calculated.
Identifier required to look up the name directly in Plants of the World Online (POWO).
Parents of hybrid.
Flag indicating whether the family to which the taxon belongs has been peer reviewed.
...
A dataset containing the taxonomic data from the WCVP (Version 15, extracted Jan 2026).
http://sftp.kew.org/pub/data-repositories/WCVP/wcvp.zip
data(wcvp_checklist_names) head(wcvp_checklist_names)data(wcvp_checklist_names) head(wcvp_checklist_names)
wcvp_version(long = TRUE)wcvp_version(long = TRUE)
long |
Whether to return the version date with version number. |
A character string containing the version and date.
wcvp_version()wcvp_version()